@@ -144,13 +144,6 @@ catalog2pdf <- function(keep.img = TRUE, overwrite = FALSE, parallel = 1, path =
     }
   }
 
-  ## update progress message
-  if (pb) {
-    reset_onexit <- .update_progress("combining images into a pdf", total = 1)
-    
-      on.exit(expr = eval(parse(text = reset_onexit)), add = TRUE)
-  }
-
   # set clusters for windows OS
   if (Sys.info()[1] == "Windows" & parallel > 1) {
     cl <- parallel::makePSOCKcluster(getOption("cl.cores", parallel))
@@ -159,7 +152,7 @@ catalog2pdf <- function(keep.img = TRUE, overwrite = FALSE, parallel = 1, path =
   }
 
   # run loop apply function
-  a1 <- pblapply_wrblr_int(pbar = pb, X = unique(or.sf), cl = cl, FUN = function(i) {
+  a1 <- .pblapply(pbar = pb, X = unique(or.sf), cl = cl, message = "combining images into a pdf", current = 1, total = 1, FUN = function(i) {
     cat2pdfFUN(i, overwrite, keep.img)
   })
 }
